@@ -1,24 +1,22 @@
 //! Check if a reduction makes file smaller, and keep best reductions.
 //! Works asynchronously when possible
 
-use crate::atomicmin::AtomicMin;
-use crate::deflate;
-use crate::filters::RowFilter;
-use crate::png::PngImage;
 #[cfg(not(feature = "parallel"))]
-use crate::rayon;
-use crate::Deadline;
-use crate::PngError;
+use std::cell::RefCell;
+use std::sync::{
+    atomic::{AtomicUsize, Ordering::*},
+    Arc,
+};
+
 #[cfg(feature = "parallel")]
 use crossbeam_channel::{unbounded, Receiver, Sender};
 use indexmap::IndexSet;
 use log::trace;
 use rayon::prelude::*;
+
 #[cfg(not(feature = "parallel"))]
-use std::cell::RefCell;
-use std::sync::atomic::AtomicUsize;
-use std::sync::atomic::Ordering::*;
-use std::sync::Arc;
+use crate::rayon;
+use crate::{atomicmin::AtomicMin, deflate, filters::RowFilter, png::PngImage, Deadline, PngError};
 
 pub struct Candidate {
     pub image: Arc<PngImage>,
@@ -110,6 +108,12 @@ impl Evaluator {
 
     /// Check if the image is smaller than others
     pub fn try_image(&self, image: Arc<PngImage>) {
+        let description = format!("{}", image.ihdr.color_type);
+        self.try_image_with_description(image, &description);
+    }
+
+    /// Check if the image is smaller than others, with a description for verbose mode
+    pub fn try_image_with_description(&self, image: Arc<PngImage>, description: &str) {
         let nth = self.nth.fetch_add(1, SeqCst);
         // These clones are only cheap refcounts
         let deadline = self.deadline.clone();
@@ -118,6 +122,7 @@ impl Evaluator {
         let optimize_alpha = self.optimize_alpha;
         let executed = self.executed.clone();
         let best_candidate_size = self.best_candidate_size.clone();
+        let description = description.to_string();
         // sends it off asynchronously for compression,
         // but results will be collected via the message queue
         #[cfg(feature = "parallel")]
@@ -140,9 +145,9 @@ impl Evaluator {
                     let size = idat_data.len() + image.key_chunks_size();
                     best_candidate_size.set_min(size);
                     trace!(
-                        "Eval: {}-bit {:20}  {:8}   {} bytes",
+                        "Eval: {}-bit {:23} {:8}   {} bytes",
                         image.ihdr.bit_depth,
-                        image.ihdr.color_type,
+                        description,
                         filter,
                         size
                     );
@@ -168,9 +173,9 @@ impl Evaluator {
                     }
                 } else if let Err(PngError::DeflatedDataTooLong(size)) = idat_data {
                     trace!(
-                        "Eval: {}-bit {:20}  {:8}  >{} bytes",
+                        "Eval: {}-bit {:23} {:8}  >{} bytes",
                         image.ihdr.bit_depth,
-                        image.ihdr.color_type,
+                        description,
                         filter,
                         size
                     );
