@@ -1,14 +1,16 @@
-use crate::colors::{BitDepth, ColorType};
-use crate::deflate::{crc32, inflate};
-use crate::error::PngError;
-use crate::interlace::Interlacing;
-use crate::AtomicMin;
-use crate::Deflaters;
-use crate::PngResult;
 use indexmap::IndexSet;
 use log::warn;
 use rgb::{RGB16, RGBA8};
 
+use crate::{
+    colors::{BitDepth, ColorType},
+    deflate::{crc32, inflate},
+    display_chunks::DISPLAY_CHUNKS,
+    error::PngError,
+    interlace::Interlacing,
+    AtomicMin, Deflaters, PngResult,
+};
+
 #[derive(Debug, Clone)]
 /// Headers from the IHDR chunk of the image
 pub struct IhdrData {
@@ -76,7 +78,7 @@ pub enum StripChunks {
     None,
     /// Remove specific chunks
     Strip(IndexSet<[u8; 4]>),
-    /// Remove all chunks that won't affect rendering
+    /// Remove all chunks that won't affect image display
     Safe,
     /// Remove all non-critical chunks except these
     Keep(IndexSet<[u8; 4]>),
@@ -85,17 +87,12 @@ pub enum StripChunks {
 }
 
 impl StripChunks {
-    /// List of chunks that will be kept when using the `Safe` option
-    pub const KEEP_SAFE: [[u8; 4]; 7] = [
-        *b"cICP", *b"iCCP", *b"sRGB", *b"pHYs", *b"acTL", *b"fcTL", *b"fdAT",
-    ];
-
     pub(crate) fn keep(&self, name: &[u8; 4]) -> bool {
         match &self {
             StripChunks::None => true,
             StripChunks::Keep(names) => names.contains(name),
             StripChunks::Strip(names) => !names.contains(name),
-            StripChunks::Safe => Self::KEEP_SAFE.contains(name),
+            StripChunks::Safe => DISPLAY_CHUNKS.contains(name),
             StripChunks::All => false,
         }
     }
