@@ -157,7 +157,8 @@ fn collect_files(
 fn apply_glob_pattern(path: PathBuf) -> Vec<PathBuf> {
     let matches = path
         .to_str()
-        .and_then(|pattern| glob::glob(pattern).ok())
+        // Use MatchOptions::default() to disable case-sensitivity
+        .and_then(|pattern| glob::glob_with(pattern, glob::MatchOptions::default()).ok())
         .map(|paths| paths.flatten().collect::<Vec<_>>());
 
     match matches {
@@ -328,10 +329,10 @@ fn parse_opts_into_struct(
         if let Some(iterations) = NonZeroU8::new(15) {
             opts.deflate = Deflaters::Zopfli { iterations };
         }
-    } else if let Deflaters::Libdeflater { compression } = &mut opts.deflate {
-        if let Some(x) = matches.get_one::<i64>("compression") {
-            *compression = *x as u8;
-        }
+    } else if let (Deflaters::Libdeflater { compression }, Some(x)) =
+        (&mut opts.deflate, matches.get_one::<i64>("compression"))
+    {
+        *compression = *x as u8;
     }
 
     #[cfg(feature = "parallel")]
