@@ -1,10 +1,10 @@
-use indexmap::IndexSet;
-use oxipng::internal_tests::*;
-use oxipng::*;
-use std::fs::remove_file;
-use std::path::Path;
-use std::path::PathBuf;
-use std::sync::Arc;
+use std::{
+    fs::remove_file,
+    path::{Path, PathBuf},
+    sync::Arc,
+};
+
+use oxipng::{internal_tests::*, *};
 
 const GRAYSCALE: u8 = 0;
 const RGB: u8 = 2;
@@ -315,21 +315,6 @@ fn issue_129() {
     );
 }
 
-#[test]
-fn issue_133() {
-    let input = "tests/files/issue-133.png";
-    let (output, mut opts) = get_opts(Path::new(input));
-    opts.optimize_alpha = true;
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        RGBA,
-        BitDepth::Eight,
-        RGBA,
-        BitDepth::Eight,
-    );
-}
-
 #[test]
 fn issue_140() {
     test_it_converts(
